@@ -4,12 +4,12 @@
 <context>
     <name>AccessPointGUI</name>
     <message>
-        <location filename="src/accesspointgui.cpp" line="41"/>
+        <location filename="src/accesspointgui.cpp" line="43"/>
         <source>Invalid key</source>
         <translation>Clé invalide</translation>
     </message>
     <message>
-        <location filename="src/accesspointgui.cpp" line="41"/>
+        <location filename="src/accesspointgui.cpp" line="43"/>
         <source>Keys must have a length of 5 or 13. Your key has been tweaked according to this.</source>
         <translation>Les clés doivent avoir une longueur de 5 ou 13. La clé a été changée selon ce critère.</translation>
     </message>
@@ -18,34 +18,41 @@
     <name>AccessPointGUIClass</name>
     <message>
         <location filename="src/accesspointgui.ui" line="14"/>
-        <location filename="src/ui_accesspointgui.h" line="104"/>
+        <location filename="src/ui_accesspointgui.h" line="110"/>
         <source>Access Point</source>
         <translation>Hotspot Wifi</translation>
     </message>
     <message>
         <location filename="src/accesspointgui.ui" line="29"/>
-        <location filename="src/ui_accesspointgui.h" line="105"/>
+        <location filename="src/ui_accesspointgui.h" line="111"/>
         <source>Hotspot name :</source>
         <translation>Nom :</translation>
     </message>
     <message>
         <location filename="src/accesspointgui.ui" line="39"/>
-        <location filename="src/ui_accesspointgui.h" line="106"/>
+        <location filename="src/ui_accesspointgui.h" line="112"/>
         <source>Security :</source>
         <translation>Sécurité :</translation>
     </message>
     <message>
         <location filename="src/accesspointgui.ui" line="59"/>
-        <location filename="src/ui_accesspointgui.h" line="107"/>
+        <location filename="src/ui_accesspointgui.h" line="113"/>
         <source>Key :</source>
         <translation>Clé :</translation>
     </message>
     <message>
         <location filename="src/accesspointgui.ui" line="66"/>
-        <location filename="src/ui_accesspointgui.h" line="108"/>
+        <location filename="src/ui_accesspointgui.h" line="114"/>
         <source>Enable WEP encryption</source>
         <translation>Activer le cryptage WEP</translation>
     </message>
+    <message>
+        <location filename="src/accesspointgui.ui" line="73"/>
+        <location filename="src/ui_accesspointgui.h" line="115"/>
+        <source>Reset the Wifi driver at startup/shutdown</source>
+        <oldsource>Reset the Wifi driver on startup/shutdown</oldsource>
+        <translation>Redémarrer le driver Wifi à l&apos;activation / arrêt</translation>
+    </message>
     <message>
         <source>Disable power-saving</source>
         <oldsource>Enable power management</oldsource>
@@ -55,33 +62,33 @@
 <context>
     <name>InternetAccessGUI</name>
     <message>
-        <location filename="src/internetaccessgui.cpp" line="15"/>
+        <location filename="src/internetaccessgui.cpp" line="19"/>
         <source>No change</source>
         <translation>Ne pas changer</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.cpp" line="16"/>
+        <location filename="src/internetaccessgui.cpp" line="20"/>
         <source>2G only</source>
         <translation>2G seulement</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.cpp" line="17"/>
+        <location filename="src/internetaccessgui.cpp" line="21"/>
         <source>3G only</source>
         <translation>3G seulement</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.cpp" line="18"/>
+        <location filename="src/internetaccessgui.cpp" line="22"/>
         <source>2G/3G</source>
         <oldsource>2G &amp; 3G</oldsource>
         <translation>2G/3G</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.cpp" line="79"/>
+        <location filename="src/internetaccessgui.cpp" line="190"/>
         <source>Invalid network</source>
         <translation>Réseau invalide</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.cpp" line="79"/>
+        <location filename="src/internetaccessgui.cpp" line="190"/>
         <source>The entered network is invalid. The default value will be used.</source>
         <translation>Le réseau indiqué est invalide. La valeur par défaut sera utilisée.</translation>
     </message>
@@ -90,35 +97,42 @@
     <name>InternetAccessGUIClass</name>
     <message>
         <location filename="src/internetaccessgui.ui" line="14"/>
-        <location filename="src/ui_internetaccessgui.h" line="109"/>
+        <location filename="src/ui_internetaccessgui.h" line="117"/>
         <source>Networking</source>
         <translation>Réseau</translation>
     </message>
     <message>
         <location filename="src/internetaccessgui.ui" line="29"/>
-        <location filename="src/ui_internetaccessgui.h" line="110"/>
-        <source>APN name : </source>
-        <translation>Nom APN :</translation>
+        <location filename="src/ui_internetaccessgui.h" line="118"/>
+        <source>APN : </source>
+        <oldsource>APN name : </oldsource>
+        <translation>APN :</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.ui" line="39"/>
-        <location filename="src/ui_internetaccessgui.h" line="111"/>
+        <location filename="src/internetaccessgui.ui" line="36"/>
+        <location filename="src/ui_internetaccessgui.h" line="119"/>
         <source>LAN IP (/24) :</source>
         <oldsource>Network IP (/24) :</oldsource>
         <translation>IP LAN (/24) :</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.ui" line="49"/>
-        <location filename="src/ui_internetaccessgui.h" line="112"/>
+        <location filename="src/internetaccessgui.ui" line="46"/>
+        <location filename="src/ui_internetaccessgui.h" line="120"/>
         <source>Share internet access</source>
         <translation>Partage internet</translation>
     </message>
     <message>
-        <location filename="src/internetaccessgui.ui" line="59"/>
-        <location filename="src/ui_internetaccessgui.h" line="113"/>
+        <location filename="src/internetaccessgui.ui" line="56"/>
+        <location filename="src/ui_internetaccessgui.h" line="121"/>
         <source>2G/3G switcher :</source>
         <translation>Switch 2G/3G :</translation>
     </message>
+    <message>
+        <location filename="src/internetaccessgui.ui" line="69"/>
+        <location filename="src/ui_internetaccessgui.h" line="122"/>
+        <source>Refresh</source>
+        <translation>Actualiser</translation>
+    </message>
 </context>
 <context>
     <name>MobileHotspotConfiguration</name>
@@ -130,12 +144,12 @@
 <context>
     <name>MobileHotspotGUI</name>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="50"/>
+        <location filename="src/mobilehotspotgui.cpp" line="51"/>
         <source>Closing the program</source>
         <translation>Fermeture</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="50"/>
+        <location filename="src/mobilehotspotgui.cpp" line="51"/>
         <source>Hotspot is still active ! Do you want to stop it ?</source>
         <translation>Le hotspot est actif ! Voulez-vous l&apos;arrêter ?</translation>
     </message>
@@ -160,12 +174,12 @@
         <translation type="obsolete">A propos...</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="144"/>
+        <location filename="src/mobilehotspotgui.cpp" line="146"/>
         <source>WEP</source>
         <translation>WEP</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="144"/>
+        <location filename="src/mobilehotspotgui.cpp" line="146"/>
         <source>No encryption</source>
         <translation>Non-crypté</translation>
     </message>
@@ -182,154 +196,160 @@
         <translation type="obsolete">Sans économie d&apos;énergie</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="152"/>
+        <location filename="src/mobilehotspotgui.cpp" line="148"/>
+        <source>Reset Wifi driver</source>
+        <oldsource>Reset WLAN driver</oldsource>
+        <translation>Redémarrage du driver Wifi</translation>
+    </message>
+    <message>
+        <location filename="src/mobilehotspotgui.cpp" line="156"/>
         <source>2G</source>
         <translation>2G</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="154"/>
+        <location filename="src/mobilehotspotgui.cpp" line="158"/>
         <source>3G</source>
         <translation>3G</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="156"/>
+        <location filename="src/mobilehotspotgui.cpp" line="160"/>
         <source>2G/3G</source>
         <oldsource>2G &amp; 3G</oldsource>
         <translation>2G/3G</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="161"/>
+        <location filename="src/mobilehotspotgui.cpp" line="165"/>
         <source>With internet</source>
         <translation>Avec internet</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="161"/>
+        <location filename="src/mobilehotspotgui.cpp" line="165"/>
         <source>Without internet</source>
         <translation>Sans internet</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="165"/>
+        <location filename="src/mobilehotspotgui.cpp" line="169"/>
         <source>Wifi</source>
         <translation>Wifi</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="166"/>
+        <location filename="src/mobilehotspotgui.cpp" line="170"/>
         <source>USB</source>
         <translation>USB</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="171"/>
+        <location filename="src/mobilehotspotgui.cpp" line="175"/>
         <source>USB For Windows Setup</source>
         <translation>Assistant USB pour Windows</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="178"/>
+        <location filename="src/mobilehotspotgui.cpp" line="182"/>
         <source>This will help you into installing the USB networking driver into Windows. Please disconnect your N900 from your computer before continuing.</source>
         <translation>Ceci vous aidera à installer le driver réseau USB pour Windows. Veuillez déconnecter votre N900 du PC avant de continuer.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="182"/>
+        <location filename="src/mobilehotspotgui.cpp" line="186"/>
         <source>First, ensure that you have copied the windows-usb-driver folder from /opt/qtmobilehotspot/docs (or QtMobileHotspot-Driver when connected in mass-storage mode) to your computer. If this is not the case, stop this assistant, and copy the folder.</source>
         <oldsource>First, ensure that you have copied the windows-usb-driver folder from /opt/qtmobilehotspot/docs (or QtMobileHotspot-Driver when connected via USB) to your computer. If this is not the case, stop this assistant, and copy the driver.</oldsource>
         <translation>D&apos;abord, vous devez avoir copié le dossier windows-usb-driver depuis /opt/qtmobilehotspot/docs (ou QtMobileHotspot-Driver quand vous êtes connecté en mode stockage de masse) sur votre ordinateur. Si ce n&apos;est pas le cas, veuillez fermer cet assistant, le faire, et recommencer.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="186"/>
+        <location filename="src/mobilehotspotgui.cpp" line="190"/>
         <source>We are now going to unload every USB module and load the one for USB networking. Ensure that you are disconnected from your PC and that your N900 isn&apos;t in any USB mode (no PC-Suite, no mass-storage).</source>
         <translation>Nous allons décharger tous les modules USB et charger celui du réseau USB. Vérifiez que vous êtes déconnecté de votre PC et qu&apos;aucun mode USB n&apos;est actif (ni PC-Suite, ni stockage de masse).</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="193"/>
+        <location filename="src/mobilehotspotgui.cpp" line="197"/>
         <source>It seems that the USB device is busy. Usually it is due to a USB-mode being active (mass storage / pc-suite). Please stop this mode and try again.</source>
         <translation>Le port USB est occupé. C&apos;est en général dû à un mode USB actif (stockage de masse / pc-suite). Veuillez arrêter ce mode et recommencer.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="198"/>
+        <location filename="src/mobilehotspotgui.cpp" line="202"/>
         <source>The system failed to load the standard g_ether USB module. It may be due to a missing power-kernel or to a system in an inconsistent state. Please try again later.</source>
         <translation>Le N900 n&apos;a pas pu charger le driver g_ether. Cela peut être dû à un power-kernel manquant ou à un état inconsistant du système. Réessayez plus tard.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="203"/>
+        <location filename="src/mobilehotspotgui.cpp" line="207"/>
         <source>The system failed to turn on the USB interface. It may be due to a system in an inconsistent state, please try again later.</source>
         <translation>Le N900 n&apos;a pas pu démarrer l&apos;interface USB. Ceci peut être dû à un système dans un état inconsistant. Veuillez réessayer plus tard.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="208"/>
+        <location filename="src/mobilehotspotgui.cpp" line="212"/>
         <source>Everything seems to be fine on your N900. You can now connect it to your computer, then continue. Do not select any USB-mode when asked.</source>
         <translation>Tout est prêt côté N900. Vous pouvez maintenant le connecter au PC. Ne sélectionnez aucun mode USB quand demandé.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="212"/>
+        <location filename="src/mobilehotspotgui.cpp" line="216"/>
         <source>Are you running Windows 7 / Windows Vista ?</source>
         <translation>Utilisez-vous Windows 7 / Windows Vista ?</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="214"/>
+        <location filename="src/mobilehotspotgui.cpp" line="218"/>
         <source>The computer will ask you about drivers. Tell it that you want to do an expert install (pick the driver yourself).</source>
         <translation>L&apos;ordinateur devra installer un nouveau driver. Dites-lui de faire une installation en mode expert (choisir le driver soit-même).</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="218"/>
+        <location filename="src/mobilehotspotgui.cpp" line="222"/>
         <source>Now edit the settings in order to make Windows use your windows-usb-driver folder. Make sure not to forget any useful checkbox.</source>
         <translation>Editez les paramètres afin que Windows cherche dans le dossier windows-usb-driver. N&apos;oubliez aucune case à cocher utile.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="223"/>
+        <location filename="src/mobilehotspotgui.cpp" line="227"/>
         <source>The computer will try to install a driver automatically (usually). It will fail, that is normal.</source>
         <translation>L&apos;ordinateur va tenter d&apos;installer un driver automatiquement (normalement). Ceci va échouer, c&apos;est normal.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="227"/>
+        <location filename="src/mobilehotspotgui.cpp" line="231"/>
         <source>Now go to the device manager (control panel, system, device manager). You should see an unknown device called Linux Ethernet RNDIS. Right-click on it, and choose Update driver.</source>
         <translation>A présent rendez-vous dans le gestionnaire de périphériques (panneau config, système, gestion périphériques). Vous devriez voir un périphérique inconnu appelé Linux Ethernet RNDIS. Faites un clic droit dessus, et choisissez Mettre à jour le pilote.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="231"/>
+        <location filename="src/mobilehotspotgui.cpp" line="235"/>
         <source>Choose to pick the driver yourself, and tell the program about your windows-usb-driver folder. Do not miss any important checkbox.</source>
         <translation>Choisissez de trouver vous même le driver à utiliser, et indiquez au programme l&apos;emplacement de votre dossier windows-usb-driver. N&apos;oubliez pas de cocher les cases qui vous concernent.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="236"/>
+        <location filename="src/mobilehotspotgui.cpp" line="240"/>
         <source>Your computer will now install the USB networking driver. If everything goes fine, congratulations, you have a new network device available in the devices-list.</source>
         <translation>L&apos;ordinateur installe maintenant le driver, patientez. Si tout se passe bien bravo, vous avez une nouvelle carte réseau dans votre liste.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="240"/>
+        <location filename="src/mobilehotspotgui.cpp" line="244"/>
         <source>You are now ready to use the program in USB mode with your Windows. Just remember to never use pc-suite/mass-storage modes when you enable USB networking.</source>
         <translation>Vous êtes prêt à utiliser le programme en mode USB avec Windows. Rappelez-vous de ne jamais utiliser la navigation USB en mode PC-Suite ou stockage de masse.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="244"/>
+        <location filename="src/mobilehotspotgui.cpp" line="248"/>
         <source>Windows should not need more configuration in order to be used with qtmobilehotspot. Simply run qtmobilehotspot, start in USB mode, plug your N900 into your PC, and enjoy.</source>
         <translation>Windows ne devrait plus avoir besoin de configuration supplémentaire. Lancez qtmobilehotspot, démarrez en mode USB, branchez le N900 au PC, et amusez-vous.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="248"/>
+        <location filename="src/mobilehotspotgui.cpp" line="252"/>
         <source>Please note that if you are already using MADDE on your computer, you may have to reset your new network card settings to automatic.</source>
         <translation>Notez que si vous utilisez déjà MADDE sur votre ordinateur, vous pouvez avoir à modifier les paramètres de la nouvelle carte réseau en automatique.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="257"/>
+        <location filename="src/mobilehotspotgui.cpp" line="261"/>
         <source>Please disconnect your N900 from your computer. We are going to unload the USB module and load the normal Nokia one. Do not choose any USB mode if you plan to use qtmobilehotspot.</source>
         <translation>Veuillez débrancher le N900 du PC. Nous allons décharger le module USB et recharger le module Nokia normal. Ne choisissez aucun mode USB si vous prévoyez d&apos;utiliser qtmobilehotspot.</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="359"/>
+        <location filename="src/mobilehotspotgui.cpp" line="340"/>
         <source>Error : LAN and Internet are both using the Wifi interface, please use a LAN on USB</source>
         <translation>Erreur : Le LAN et Internet sont tous deux sur l&apos;interface Wifi, veuillez utiliser un LAN sur USB</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="360"/>
+        <location filename="src/mobilehotspotgui.cpp" line="341"/>
         <source>Cannot start</source>
         <translation>Impossible de démarrer</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="425"/>
+        <location filename="src/mobilehotspotgui.cpp" line="406"/>
         <source>Error : USB shouldn&apos;t be in any mode (no storage mode, no pc-suite mode)</source>
         <translation>Erreur : Aucun mode USB ne devrait être actif (ni stockage de masse, ni PC-Suite)</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="430"/>
+        <location filename="src/mobilehotspotgui.cpp" line="411"/>
         <source>Error while loading standard g_ether driver</source>
         <oldsource>Error while switching from nokia&apos;s modules to standard ones</oldsource>
         <translation>Erreur au chargement du driver g_ether</translation>
@@ -343,20 +363,21 @@
         <translation type="obsolete">Paramètres invalides</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="382"/>
+        <location filename="src/mobilehotspotgui.cpp" line="363"/>
         <source>Error while loading system modules, are you running the power kernel ?</source>
         <translation>Erreur au chargement des modules système. Utilisez-vous le power-kernel ?</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="395"/>
-        <location filename="src/mobilehotspotgui.cpp" line="407"/>
+        <location filename="src/mobilehotspotgui.cpp" line="376"/>
+        <location filename="src/mobilehotspotgui.cpp" line="388"/>
         <source>Error while disconnecting previous internet connection</source>
         <translation>Erreur à la désactivation de la connection internet</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="400"/>
-        <source>Error while connecting to the chosen APN</source>
-        <translation>Erreur à la connection à l&apos;APN choisi</translation>
+        <location filename="src/mobilehotspotgui.cpp" line="381"/>
+        <source>Error while connecting to the APN, you way need to select it again in the Networking panel</source>
+        <oldsource>Error while connecting to the chosen APN</oldsource>
+        <translation>Erreur à la connection à l&apos;APN choisi, essayez de le re-sélectionner dans la configuration réseau</translation>
     </message>
     <message>
         <source>Error while checking USB mode, are you in PC Suite mode ?</source>
@@ -367,22 +388,21 @@
         <translation type="obsolete">Erreur lors du passage de g_nokia vers g_ether</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="438"/>
+        <location filename="src/mobilehotspotgui.cpp" line="419"/>
         <source>Error while preparing the USB interface</source>
         <translation>Erreur à la préparation de l&apos;interface USB</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="446"/>
+        <location filename="src/mobilehotspotgui.cpp" line="427"/>
         <source>Error while preparing the Wifi interface</source>
         <translation>Erreur à la préparation de l&apos;interface Wifi</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="452"/>
         <source>Error (timeout) while stopping the DHCP/DNS server</source>
-        <translation>Erreur (timeout) à l&apos;arrêt du serveur DNS/DHCP</translation>
+        <translation type="obsolete">Erreur (timeout) à l&apos;arrêt du serveur DNS/DHCP</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="473"/>
+        <location filename="src/mobilehotspotgui.cpp" line="448"/>
         <source>Failed to start the hotspot</source>
         <translation>Echec du démarrage du hotspot</translation>
     </message>
@@ -395,17 +415,17 @@
         <translation type="obsolete">Sans économie d&apos;énergie</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="504"/>
+        <location filename="src/mobilehotspotgui.cpp" line="479"/>
         <source>Hotspot started successfully</source>
         <translation>Hotspot démarré avec succès</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="668"/>
+        <location filename="src/mobilehotspotgui.cpp" line="648"/>
         <source>Hotspot stopped successfully</source>
         <translation>Hotspot arrêté avec succès</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.cpp" line="668"/>
+        <location filename="src/mobilehotspotgui.cpp" line="648"/>
         <source>Hotspot stopped with errors</source>
         <translation>Hotspot arrêté avec erreurs</translation>
     </message>
@@ -414,25 +434,31 @@
     <name>MobileHotspotGUIClass</name>
     <message>
         <location filename="src/mobilehotspotgui.ui" line="14"/>
-        <location filename="src/ui_mobilehotspotgui.h" line="196"/>
+        <location filename="src/ui_mobilehotspotgui.h" line="200"/>
         <source>Qt Mobile Hotspot</source>
         <translation>Qt Mobile Hotspot</translation>
     </message>
     <message>
         <location filename="src/mobilehotspotgui.ui" line="53"/>
-        <location filename="src/ui_mobilehotspotgui.h" line="199"/>
+        <location filename="src/ui_mobilehotspotgui.h" line="203"/>
         <source>Start</source>
         <translation>Démarrer</translation>
     </message>
     <message>
         <location filename="src/mobilehotspotgui.ui" line="82"/>
-        <location filename="src/ui_mobilehotspotgui.h" line="200"/>
+        <location filename="src/ui_mobilehotspotgui.h" line="204"/>
         <source>Stop</source>
         <translation>Arrêter</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.ui" line="226"/>
-        <location filename="src/ui_mobilehotspotgui.h" line="198"/>
+        <location filename="src/mobilehotspotgui.ui" line="218"/>
+        <location filename="src/ui_mobilehotspotgui.h" line="208"/>
+        <source>File</source>
+        <translation>Fichier</translation>
+    </message>
+    <message>
+        <location filename="src/mobilehotspotgui.ui" line="232"/>
+        <location filename="src/ui_mobilehotspotgui.h" line="202"/>
         <source>USB For Windows Setup</source>
         <translation>USB pour Windows</translation>
     </message>
@@ -442,13 +468,13 @@
     </message>
     <message>
         <location filename="src/mobilehotspotgui.ui" line="152"/>
-        <location filename="src/ui_mobilehotspotgui.h" line="201"/>
+        <location filename="src/ui_mobilehotspotgui.h" line="205"/>
         <source>Wifi...</source>
         <translation>Wifi...</translation>
     </message>
     <message>
         <location filename="src/mobilehotspotgui.ui" line="191"/>
-        <location filename="src/ui_mobilehotspotgui.h" line="202"/>
+        <location filename="src/ui_mobilehotspotgui.h" line="206"/>
         <source>Networking...</source>
         <oldsource>Network settings...</oldsource>
         <translation>Réseau...</translation>
@@ -459,13 +485,13 @@
     </message>
     <message>
         <location filename="src/mobilehotspotgui.ui" line="213"/>
-        <location filename="src/ui_mobilehotspotgui.h" line="203"/>
+        <location filename="src/ui_mobilehotspotgui.h" line="207"/>
         <source>Plugins</source>
         <translation>Plugins</translation>
     </message>
     <message>
-        <location filename="src/mobilehotspotgui.ui" line="221"/>
-        <location filename="src/ui_mobilehotspotgui.h" line="197"/>
+        <location filename="src/mobilehotspotgui.ui" line="227"/>
+        <location filename="src/ui_mobilehotspotgui.h" line="201"/>
         <source>About Qt Mobile Hotspot</source>
         <oldsource>About qtMobileHotspot</oldsource>
         <translation>A propos de Qt Mobile Hotspot</translation>
