@@ -20,6 +20,7 @@ void AccessPointGUI::setConfiguration(MobileHotspotConfiguration &configuration)
 	ui.txtAPName->setText(configuration.hotspotName);
 	ui.chkEncryption->setChecked(configuration.encryptionType == configuration.ENCRYPTION_WEP);
 	ui.txtKey->setText(configuration.encryptionKey);
+	ui.chkWLANDriver->setChecked(configuration.cycleWlanDriver);
 }
 
 void AccessPointGUI::configuration(MobileHotspotConfiguration *configuration){
@@ -27,6 +28,7 @@ void AccessPointGUI::configuration(MobileHotspotConfiguration *configuration){
 	configuration->hotspotName = name == "" ? "N900 Hotspot" : name;
 	configuration->encryptionType = ui.chkEncryption->isChecked() ? configuration->ENCRYPTION_WEP : configuration->ENCRYPTION_NONE;
 	configuration->encryptionKey = validKey();
+	configuration->cycleWlanDriver = ui.chkWLANDriver->isChecked();
 }
 
 QString AccessPointGUI::validKey(){
