@@ -12,7 +12,7 @@ class CommandHelper
 public:
 	CommandHelper();
     ~CommandHelper();
-    static void executeCommandOld(QString command);
+    static int  executeCommandOld(QString command);
 	static void executeCommandOld(QString command, int *result);
     static bool executeCommand(QString command, int timeoutStartedMS = 10000, int timeoutFinishedMS = -1);
     static bool executeCommand(QString command, int *result, int timeoutStartedMS = 10000, int timeoutFinishedMS = -1);
