@@ -6,9 +6,9 @@
 
 
 enum Enforcement2G3G{
-	ENFORCEMENT_2G,
-	ENFORCEMENT_3G,
-	ENFORCEMENT_NONE
+	DBUS_2G3G_2G,
+	DBUS_2G3G_3G,
+	DBUS_2G3G_DOUBLE
 };
 
 
