@@ -329,6 +329,15 @@ int HotspotHelper::prepareWifiInterface(MobileHotspotConfiguration &configuratio
 	else if(ret != 0)
 		qDebug("WARNING :  Was not able to disable the Wifi interface");
 
+	if(configuration.cycleWlanDriver){
+		/** Cycle WLAN driver **/
+		ret = cycleWLANDriver(configuration);
+		if(ret != 0){
+			qDebug("Error while cycling the WLAN driver");
+			return -1;
+		}
+	}
+
 	/** Power saving - May not work on adhoc, but who knows **/
 	/** Switch to managed mode (to be able to change power management) - may fail, not fatal unless timeout **/
 	ret = setAdhocMode(configuration, false);
@@ -372,7 +381,7 @@ int HotspotHelper::prepareWifiInterface(MobileHotspotConfiguration &configuratio
 	}
 
 	/** Set ESSID **/
-	ret = setESSID(configuration);
+	ret = setESSID(configuration, true);
 	if(ret != 0){
 		qDebug("Error while setting the ESSID");
 		return -1;
@@ -519,7 +528,7 @@ int HotspotHelper::setEncryption(MobileHotspotConfiguration &configuration, bool
 	}
 	else{
 		qDebug("Will disable encryption");
-		cmd += " key off open";
+		cmd += " key open";
 	}
 	cmdret = CommandHelper::executeCommand(cmd, &ret);
 	if( (! cmdret) || (cmdret && ret != 0) ){
@@ -555,16 +564,28 @@ QString HotspotHelper::keyToHex(QString key){
 	return result;
 }
 
-int HotspotHelper::setESSID(MobileHotspotConfiguration &configuration){
+int HotspotHelper::setESSID(MobileHotspotConfiguration &configuration, bool useESSID){
 	/* -1=fail, -2=timeout, 0=ok */
 	qDebug("** Modifying ESSID **");
 	int ret, tries;
 	bool cmdret, trying;
-	QString cmd("/sbin/iwconfig "); cmd += configuration.INTERFACE_WLAN;
-	cmd += " essid \""; cmd += configuration.hotspotName + "\"";
+	QString cmd("/sbin/iwconfig "); cmd += configuration.INTERFACE_WLAN; cmd += " essid ";
+	if(useESSID)
+		cmd += QString("\"") + configuration.hotspotName + "\"";
+	else
+		cmd += "off";
 	cmdret = CommandHelper::executeCommand(cmd, &ret);
-	if( (! cmdret) || (cmdret && ret != 0) ){
-		qDebug("FAILURE : Cannot modify essid mode");
+	if(! useESSID){
+		if(! cmdret){
+			// the iwconfig of maemo5 does return an error when we use 'iwconfig wlan0 essid off'
+			// still, it does work, we really leave the IBSS
+			// so in this case we just check if the command was run, and ignore its return code
+			qDebug("FAILURE : Cannot leave IBSS");
+			return -1;
+		}
+	}
+	else if( (! cmdret) || (cmdret && ret != 0) ){
+		qDebug("FAILURE : Cannot modify essid");
 		return -1;
 	}
 	trying = true; tries = 0;
@@ -573,7 +594,10 @@ int HotspotHelper::setESSID(MobileHotspotConfiguration &configuration){
 		QString res;
 		CommandHelper::executeCommandWithStdOut(QString("/sbin/iwconfig ") + configuration.INTERFACE_WLAN, &ret, &res);
 		res = res.toLower();
-		QString searched("essid:\""); searched += configuration.hotspotName.toLower() + "\"";
+		QString searched("essid:\"");
+		if(useESSID)
+			searched += configuration.hotspotName.toLower();
+		searched += "\"";
 		if(res.count(searched) > 0)
 			trying = false;
 		else
@@ -636,6 +660,11 @@ int HotspotHelper::unprepareWifiInterface(MobileHotspotConfiguration &configurat
 	qDebug("** Unpreparing Wifi interface **");
 	int res = 0, ret;
 
+	/** Leave IBSS, may fail, not fatal **/
+	ret = setESSID(configuration, false);
+	if(ret != 0)
+		qDebug("Error while leaving the IBSS");
+
 	/** Disable Wifi interface **/
 	ret = disableWifiInterface(configuration);
 	if(ret != 0){
@@ -664,26 +693,86 @@ int HotspotHelper::unprepareWifiInterface(MobileHotspotConfiguration &configurat
 		res = -1;
 	}
 
+	if(configuration.cycleWlanDriver){
+		/** Cycle WLAN driver **/
+		ret = cycleWLANDriver(configuration);
+		if(ret != 0){
+			qDebug("Error while cycling WLAN driver");
+			res = -1;
+		}
+	}
+
 	return res;
 }
 
+int HotspotHelper::cycleWLANDriver(MobileHotspotConfiguration &configuration){
+	/** -1=fail, 0=ok **/
+	qDebug("** Unloading/reloading WLAN driver **");
+	int ret;
+	bool res;
+	QString mac;
+	QString cmd = QString("/bin/sh -c \"ifconfig ") + configuration.lanInterface + " | grep -o -E '([[:xdigit:]]{1,2}:){5}[[:xdigit:]]{1,2}'\"";
+	res = CommandHelper::executeCommandWithStdOut(cmd , &ret, &mac);
+	mac = mac.trimmed();
+	if( (! res) || (ret != 0) )
+		qDebug("WARNING : Was not able to get WLAN MAC address, it may change without us being able to restore it");
+	cmd = "rmmod wl12xx";
+	res = CommandHelper::executeCommand(cmd , &ret);
+	if( (! res) || (ret != 0) )
+		qDebug("WARNING : Was not able to remove wl12xx module");
+	cmd = "modprobe wl12xx";
+	res = CommandHelper::executeCommand(cmd, &ret);
+	if( (! res) || (ret != 0) )
+		qDebug("WARNING : Was not able to load wl12xx module");
+	cmd = QString("ifconfig ") + configuration.INTERFACE_WLAN + " down";
+	res = CommandHelper::executeCommand(cmd, &ret);
+	if( (! res) || (ret != 0) )
+		qDebug("WARNING : Was not able to down the WLAN interface");
+	cmd = (QString("ifconfig ") + configuration.INTERFACE_WLAN + " hw ether ") + mac;
+	res = CommandHelper::executeCommand(cmd, &ret);
+	if( (! res) || (ret != 0) )
+		qDebug("WARNING : Was not able to restore WLAN MAC address");
+
+	bool trying1 = true, trying2 = true;
+	int tries = 0;
+	while( (trying1 || trying2) && tries < MAX_TRIES ){
+		tries++;
+		QString s;
+		CommandHelper::executeCommandWithStdOut(QString("/sbin/ifconfig ") + configuration.INTERFACE_WLAN, &ret, &s);
+		if(s.toLower().count(mac.toLower()) > 0)
+			trying1 = false;
+		CommandHelper::executeCommandWithStdOut("lsmod", &ret, &s);
+		if(s.toLower().count("wl12xx") > 0)
+			trying2 = false;
+		if(trying1 || trying2)
+			CommandHelper::executeCommand("sleep 1");
+	}
+	if(trying1 || trying2){
+		qDebug("FAILURE : System did not pass the WLAN driver cycle step");
+		return -1;
+	}
+	return 0;
+}
+
 int HotspotHelper::startDnsMasq(MobileHotspotConfiguration &configuration, QProcess *dnsmasqProcess){
 	/** -1=fail, 0=ok **/
 	/** Credits to Rambo for the basics of the command **/
 	qDebug("** Starting dnsmasq **");
 	QString cmd("/usr/sbin/dnsmasq");
-	cmd += " --no-daemon";
-	cmd += " -i "; cmd += configuration.lanInterface;
-	cmd += " -a "; cmd += configuration.lanNetwork + "1";
-	cmd += " -I lo -z";
-	cmd += " --dhcp-range="; cmd += configuration.lanNetwork + "10,"; cmd += configuration.lanNetwork + "200,6h";
-	cmd += " --dhcp-authoritative";
+	cmd += " --no-daemon"; // not running in daemon mode, = do not fork neither run in background
+	cmd += " -i "; cmd += configuration.lanInterface; // listen on lan interface
+	cmd += " -a "; cmd += configuration.lanNetwork + "1"; // listen on our address
+	cmd += " -I lo"; // do not listen on loopback
+	cmd += " -z"; // bind only to selected interfaces
+	cmd += " --dhcp-range="; cmd += configuration.lanNetwork + "10,"; cmd += configuration.lanNetwork + "200,6h"; // dhcp range
+	cmd += " --dhcp-authoritative"; // we are an authoritative dhcp server
 	if(configuration.internetEnabled){
-		cmd += " --dhcp-option=3,";
-		cmd += configuration.lanNetwork + "1";
-		// option 3 = router
+		cmd += " --dhcp-option=3,"; cmd += configuration.lanNetwork + "1"; // dhcp option 3 = router
 	}
-	cmd += " --dhcp-option=6,"; cmd += configuration.lanNetwork + "1"; // option 6 = dns server
+	else{
+		cmd += " --port=0"; // disable DNS resolution (if <>0 then it means use this port for DNS)
+	}
+	cmd += " --dhcp-option=6,"; cmd += configuration.lanNetwork + "1"; // dhcp option 6 = dns server (we give it even if DNS is disabled, as some systems may dislike not knowing any DNS server)
 	bool cmdret = CommandHelper::executeCommandAsync(cmd, dnsmasqProcess, MAX_TRIES * 1000);
 	if(! cmdret){
 		qDebug("FAILURE : Cannot start dnsmasq");
