@@ -48,8 +48,9 @@ private:
 	static int setEncryption(MobileHotspotConfiguration &configuration, bool encryption);
 	static int setAdhocMode(MobileHotspotConfiguration &configuration, bool adhoc);
 	static QString keyToHex(QString key);
-	static int setESSID(MobileHotspotConfiguration &configuration);
+	static int setESSID(MobileHotspotConfiguration &configuration, bool useESSID);
 	static int setWifiNetwork(MobileHotspotConfiguration &configuration);
+	static int cycleWLANDriver(MobileHotspotConfiguration &configuration);
 };
 
 #endif // HOTSPOTHELPER_H
