@@ -38,6 +38,10 @@ void MobileHotspotConfiguration::load(){
 	encryptionKey = item->value("0000000000000").toString();
 	delete item;
 
+	item = new GConfItem(GCONF_WLANDRIVER);
+	cycleWlanDriver = item->value("true").toString() == "true";
+	delete item;
+
 	item = new GConfItem(GCONF_INTERFACE);
 	lanInterface = item->value(INTERFACE_WLAN).toString();
 	delete item;
@@ -92,6 +96,10 @@ void MobileHotspotConfiguration::save(){
 	item->set(encryptionKey);
 	delete item;
 
+	item = new GConfItem(GCONF_WLANDRIVER);
+	item->set(cycleWlanDriver ? "true" : "false");
+	delete item;
+
 	item = new GConfItem(GCONF_INTERFACE);
 	item->set(lanInterface);
 	delete item;
