@@ -34,7 +34,7 @@ MobileHotspotGUI::MobileHotspotGUI(QWidget *parent)
 	loadPlugins();
 	sortPlugins();
 	ui.setupUi(this);
-	displayPlugins();
+	displayPlugins(false);
 	configuration.load();
 	updateDisplayedConfiguration();
 }
@@ -109,12 +109,13 @@ void MobileHotspotGUI::sortPlugins(){
 	}
 }
 
-void MobileHotspotGUI::displayPlugins(){
+void MobileHotspotGUI::displayPlugins(bool running){
+	ui.menuPlugins->clear();
 	QList<MobileHotspotPlugin*> values = plugins.values();
 	QListIterator<MobileHotspotPlugin*> iterator(values);
 	while(iterator.hasNext()){
 		MobileHotspotPlugin *plugin = iterator.next();
-		if(plugin->displayName()){
+		if( (running && plugin->displayNameRunning()) || ((! running) && plugin->displayNameStopped()) ){
 			qApp->installTranslator(plugin->translator());
 				QAction *action = ui.menuPlugins->addAction(plugin->displayedName());
 			qApp->removeTranslator(plugin->translator());
@@ -143,6 +144,8 @@ void MobileHotspotGUI::updateDisplayedConfiguration(){
 	ui.lstAccessPoint->clear();
 	ui.lstAccessPoint->addItem(configuration.hotspotName);
 	ui.lstAccessPoint->addItem(configuration.encryptionType == configuration.ENCRYPTION_WEP ? tr("WEP") : tr("No encryption"));
+	if(configuration.cycleWlanDriver)
+		ui.lstAccessPoint->addItem(tr("Reset Wifi driver"));
 
 	ui.lstInternetAccess->clear();
 	QString s = configuration.internetAPName;
@@ -266,29 +269,6 @@ void MobileHotspotGUI::usbWindowsAssistant(){
 }
 
 void MobileHotspotGUI::configureInternetAccess(){
-	/** Find available networks **/
-	//TODO
-	/** For now we just call doConfigureInternetAccess() **/
-	doConfigureInternetAccess();
-}
-
-void MobileHotspotGUI::availableAPNsSignal(const QDBusMessage &message){
-	//TODO
-}
-
-void MobileHotspotGUI::availableAPNsEnableSignal(){
-	//TODO
-}
-
-void MobileHotspotGUI::availableAPNsDisableSignal(){
-	//TODO
-}
-
-void MobileHotspotGUI::availableAPNsRequest(){
-	//TODO
-}
-
-void MobileHotspotGUI::doConfigureInternetAccess(){
 	InternetAccessGUI gui(this);
 	gui.setConfiguration(configuration);
 	if(gui.exec() != QDialog::Accepted)
@@ -398,7 +378,7 @@ void MobileHotspotGUI::startProcedure(){
 				/** Connect to the chosen APN **/
 				ret = HotspotHelper::enableInternetConnection(configuration);
 				if(ret != 0)
-					throw QString(tr("Error while connecting to the chosen APN"));
+					throw QString(tr("Error while connecting to the APN, you way need to select it again in the Networking panel"));
 			}
 		}
 		else if(configuration.lanInterface == configuration.INTERFACE_WLAN && previousConnectionType.indexOf("WLAN") >= 0){
@@ -497,6 +477,7 @@ void MobileHotspotGUI::startProcedure(){
 	if(success){
 		if(showNotifications)
 			DBUSHelper::notificationSimple(tr("Hotspot started successfully"));
+		displayPlugins(true);
 		ui.btnAccessPoint->setEnabled(false);
 		ui.btnInternetAccess->setEnabled(false);
 		ui.lstInterfaces->setEnabled(false);
@@ -665,6 +646,7 @@ void MobileHotspotGUI::stopProcedure(){
 	/** GUI **/
 	if(showNotifications)
 		DBUSHelper::notificationSimple(success ? tr("Hotspot stopped successfully") : tr("Hotspot stopped with errors"));
+	displayPlugins(false);
 	ui.btnAccessPoint->setEnabled(true);
 	ui.btnInternetAccess->setEnabled(true);
 	ui.lstInterfaces->setEnabled(true);
