@@ -28,13 +28,10 @@ private:
 	void updateDisplayedConfiguration();
 	void loadPlugins();
 	void sortPlugins();
-	void displayPlugins();
+	void displayPlugins(bool running);
 	void previousConnectionEnableSignal();
 	void previousConnectionDisableSignal();
 	void previousConnectionRequest();
-	void availableAPNsEnableSignal();
-	void availableAPNsDisableSignal();
-	void availableAPNsRequest();
 
 	Ui::MobileHotspotGUIClass ui;
     QMap<QString, MobileHotspotPlugin*> plugins;
@@ -55,9 +52,6 @@ private:
     QString previousConnectionID;
     QString previousConnectionType;
 
-    bool waitingForAPNs;
-    QList<QStringList> availablesAPNs;
-
 protected :
         void closeEvent(QCloseEvent* event);
 
@@ -65,7 +59,6 @@ private slots:
 	void usbWindowsAssistant();
 	void configureAccessPoint();
 	void configureInternetAccess();
-	void doConfigureInternetAccess();
 	void configureInterface(int index);
 	void pluginTriggered();
 	void start(bool notification = true);
@@ -74,7 +67,6 @@ private slots:
 	void stopProcedure();
 	void bypassUSBModeWindow();
 	void previousConnectionSignal(const QDBusMessage &message);
-	void availableAPNsSignal(const QDBusMessage &message);
 };
 
 #endif // MOBILEHOTSPOTGUI_H
