@@ -11,7 +11,8 @@ class MobileHotspotPlugin{
 public:
 	virtual QString name() = 0;
 	virtual QString displayedName() = 0;
-	virtual bool displayName() = 0;
+	virtual bool displayNameStopped() = 0;
+	virtual bool displayNameRunning() = 0;
 	virtual int order() = 0;
 
 	virtual void configure(const MobileHotspotConfiguration &configuration, const bool running) = 0;
@@ -24,7 +25,7 @@ public:
 	virtual QTranslator *translator() = 0;
 };
 
-Q_DECLARE_INTERFACE(MobileHotspotPlugin, "com.dest.qtmh.plugin/0.1")
+Q_DECLARE_INTERFACE(MobileHotspotPlugin, "com.dest.qtmh.plugin/0.1.1")
 
 
 #endif // MOBILEHOTSPOTGUIPLUGIN_H
