@@ -20,7 +20,8 @@ public:
 	~Plugin();
 	QString name();
 	QString displayedName();
-	bool displayName();
+	bool displayNameStopped();
+	bool displayNameRunning();
 	int order();
 
 	void configure(const MobileHotspotConfiguration &configuration, const bool running);
