@@ -16,14 +16,12 @@
         <translation>Perso Iptables</translation>
     </message>
     <message>
-        <location filename="src/plugin.cpp" line="52"/>
         <source>Configure</source>
-        <translation>Configuration</translation>
+        <translation type="obsolete">Configuration</translation>
     </message>
     <message>
-        <location filename="src/plugin.cpp" line="52"/>
         <source>Please stop the hotspot before configuring.</source>
-        <translation>Veuillez arrêter le hotspot avant de configurer.</translation>
+        <translation type="obsolete">Veuillez arrêter le hotspot avant de configurer.</translation>
     </message>
 </context>
 <context>
