@@ -13,9 +13,10 @@ PluginConfiguration::~PluginConfiguration(){
 void PluginConfiguration::load(){
 	// Load the plugin's configuration, please use the helper function load("settingName", "defaultValue")
 	// some_variable = helper->load("settingName", "default value").toString();
-	disablePowerSaving = helper->load("disablePowerSaving", "false").toString() == "true";
+	disablePowerSaving = helper->load("disablePowerSaving", "true").toString() == "true";
 	internetPing = helper->load("internetPing", "false").toString() == "true";
 	internetPingIP = helper->load("internetPingIP", "example.com").toString();
+	wlanCheck = helper->load("wlanCheck", "true") == "true";
 }
 
 void PluginConfiguration::save(){
@@ -24,4 +25,5 @@ void PluginConfiguration::save(){
 	helper->save("disablePowerSaving", disablePowerSaving ? "true" : "false");
 	helper->save("internetPing", internetPing ? "true" : "false");
 	helper->save("internetPingIP", internetPingIP);
+	helper->save("wlanCheck", wlanCheck ? "true" : "false");
 }
