@@ -19,6 +19,7 @@ void PluginGUI::configuration(PluginConfiguration *conf){
 	conf->disablePowerSaving = ui.chkPowerSaving->isChecked();
 	conf->internetPing = ui.chkPing->isChecked();
 	conf->internetPingIP = ui.txtPingIP->text();
+	conf->wlanCheck = ui.chkWLANCheck->isChecked();
 }
 
 void PluginGUI::setConfiguration(PluginConfiguration &conf){
@@ -27,6 +28,7 @@ void PluginGUI::setConfiguration(PluginConfiguration &conf){
 	ui.chkPowerSaving->setChecked(conf.disablePowerSaving);
 	ui.chkPing->setChecked(conf.internetPing);
 	ui.txtPingIP->setText(conf.internetPingIP);
+	ui.chkWLANCheck->setChecked(conf.wlanCheck);
 }
 
 void PluginGUI::reset(){
